@@ -698,7 +698,6 @@ class DataManager:
                              jinja_parameters_dict: dict = None,
                              format_func_dict: FormatDict | dict = None, left_on: str | tuple = None,
                              left_index: bool = False,
-                             num_inserts_display_in_frame = 50,
                              override_frame_jinja_repo_source: JinjaRepo = None):
 
         """
@@ -755,8 +754,7 @@ class DataManager:
         df = query.execute_sql_string(sql, con)
 
         _frame_name = frame_name or config["meta"]["name"]
-        sql_truncated_inserts = query.truncate_sql_inserts(sql,num_inserts_display_in_frame)
-        frame = meta._Frame(_frame_name, "JinjaRepo", df, sql=sql_truncated_inserts)
+        frame = meta._Frame(_frame_name, "JinjaRepo", df, sql=sql)
 
         self._join_from_frame(frame, right_on, how, format_func_dict, None, None, False,
                               False)
@@ -891,8 +889,7 @@ class DataManager:
                              format_parameters_list: list = None,
                              frame_name: str = None, format_func_dict: FormatDict | dict = None,
                              left_on: str | tuple = None, right_on: str | tuple = None,
-                             left_index: bool = False, right_index: bool = False,
-                             num_inserts_display_in_frame = 50):
+                             left_index: bool = False, right_index: bool = False):
         """
 
         Inserts the records contained in the target population into a format SQL script template, this creates a script
@@ -981,8 +978,7 @@ class DataManager:
                                                      rename_columns_dict=_rename_dict)
         df = query.execute_sql_string(sql, connection)
 
-        sql_truncated_inserts = query.truncate_sql_inserts(sql, num_inserts_display_in_frame)
-        frame = meta._Frame(_frame_name, "Format SQL", df, sql=sql_truncated_inserts)
+        frame = meta._Frame(_frame_name, "Format SQL", df, sql=sql)
         self._join_from_frame(frame, on, how, format_func_dict, left_on, right_on, left_index,
                               right_index)
 
@@ -991,8 +987,7 @@ class DataManager:
                         jinja_parameters_dict: dict = None,
                         frame_name: str = None, format_func_dict: dict = None,
                         left_on: str | tuple = None, right_on: str | tuple = None,
-                        left_index: bool = False, right_index: bool = False,
-                        num_inserts_display_in_frame = 50):
+                        left_index: bool = False, right_index: bool = False):
 
         """
 
@@ -1079,8 +1074,7 @@ class DataManager:
                                                 rename_columns_dict=_rename_dict)
         df = query.execute_sql_string(sql, connection)
 
-        sql_truncated_inserts = query.truncate_sql_inserts(sql, num_inserts_display_in_frame)
-        frame = meta._Frame(_frame_name, "Jinja", df, sql=sql_truncated_inserts)
+        frame = meta._Frame(_frame_name, "Jinja", df, sql=sql)
         self._join_from_frame(frame, on, how, format_func_dict, left_on, right_on, left_index,
                               right_index)
 
